@@ -91,6 +91,15 @@ class AccuracyMetricsTests(BaseMetricsTests):
         self.assertMeasureAlmostEqual(meter_minimum, [(a, t3)], 0)
         self.assertMeasureAlmostEqual(meter_minimum, [(a, t4)], 0)
 
+    def test_cannot_measure_with_other_type_than_tensors(self):
+        meter = meters.CategoricalAccuracy()
+
+        try:
+            meter.measure([0.9, 0.1], [1])
+            self.fail()
+        except TypeError as e:
+            self.assertEqual(str(e), meter.INVALID_INPUT_TYPE_MESSAGE)
+
     def test_cannot_measure_with_1d_tensors(self):
         a = torch.Tensor([0.1])
         t = torch.LongTensor([0])
@@ -314,7 +323,7 @@ class ConfusionMatrixTests(BaseMetricsTests):
         return self.assertEqual(a.tolist(), b.tolist())
 
     def assertMeasureEqual(self, meter, batchs, measure):
-        self.assertTensorsEqual(self.measure_once(meter, batchs), measure)
+        self.assertTensorsEqual(self.measure_once(meter, batchs).matrix, measure)
 
     def test_can_not_create_meter_with_negative_classes(self):
         try:
@@ -403,7 +412,7 @@ class ConfusionMatrixTests(BaseMetricsTests):
             self.assertEqual(str(e), meter.INVALID_LABELS_MESSAGE)
 
     def test_meter_returns_zero_before_measurements(self):
-        self.assertTensorsEqual(meters.ConfusionMatrix(nr_classes=2).value(), torch.zeros(2, 2))
+        self.assertTensorsEqual(meters.ConfusionMatrix(nr_classes=2).value().matrix, torch.zeros(2, 2))
 
     def test_confusion_matrix_with_two_classes_count_one_each_class(self):
         meter = meters.ConfusionMatrix(nr_classes=2)
@@ -490,3 +499,44 @@ class BalancedAccuracyTests(BaseMetricsTests):
                                                             [0, 1, 0],  # 1
                                                             [0, 0, 1]]), # 2
                                                torch.LongTensor([0,1,0,2]))], (1/2+1/1+1/1)/3)
+
+class BinaryScores(BaseMetricsTests):
+    def setUp(self):
+        self.batch_1 = [(torch.LongTensor([1,1,1,0,0,1]),
+                         torch.LongTensor([1,0,1,0,1,0]))]
+        self.batch_2 = [(# Batch 1
+                         torch.LongTensor([1,1,1]),
+                         torch.LongTensor([1,0,1])),
+                         ## Batch 2
+                        (torch.LongTensor([0,0,1]),
+                         torch.LongTensor([0,1,0]))]
+
+    def test_1_batch_precision(self):
+        meter = meters.Precision()
+        self.assertMeasureAlmostEqual(meter, self.batch_1, 2/4)
+
+    def test_1_batch_recall(self):
+        meter = meters.Recall()
+        self.assertMeasureAlmostEqual(meter, self.batch_1, 2/3)
+
+    def test_2_batch_recall(self):
+        meter = meters.Recall()
+        meter.measure(*self.batch_2[0])
+        self.assertAlmostEqual(meter.value(), 2/2)
+        meter.measure(*self.batch_2[1])
+        self.assertAlmostEqual(meter.value(), 2/3)
+        meter.reset()
+        meter.measure(*self.batch_2[1])
+        self.assertAlmostEqual(meter.value(), 0)
+
+    def test_1_batch_specifity(self):
+        meter = meters.Specificity()
+        self.assertMeasureAlmostEqual(meter, self.batch_1, 1/3)
+
+    def test_1_batch_npv(self):
+        meter = meters.NPV()
+        self.assertMeasureAlmostEqual(meter, self.batch_1, 1/2)
+
+    def test_1_batch_f1_score(self):
+        meter = meters.F1Score()
+        self.assertMeasureAlmostEqual(meter, self.batch_1, 2 * (2/4 * 2/3) / (2/4 + 2/3))
